import { rest } from 'msw';
import { mockAdoptersCategorizedByWorkingGroup } from './mock-data';

const apiUrl = 'https://api.eclipse.org/adopters';

const handlers = [
    rest.get(`${apiUrl}/projects`, (req, res, ctx) => {
        const workingGroup = req.url.searchParams.get('working_group');
        const page = +req.url.searchParams.get('page') || 1;
        const pageSize = 3;

        if (!workingGroup) return res(ctx.status(400));

        const projects = mockAdoptersCategorizedByWorkingGroup[workingGroup] || [];

        const hasMoreProjects = (page * pageSize) < projects.length;

        const linkHeaderBase = `<${apiUrl}/projects?working_group=${workingGroup}&page=${page}>;rel=self`
        const linkHeaderText = hasMoreProjects 
            ? `${linkHeaderBase}, <${ apiUrl }/projects?working_group=${ workingGroup }&page=${ page + 1 }>; rel=next`
            : linkHeaderBase;

        return res(
            ctx.status(200),
            ctx.set({
                'Link': linkHeaderText
            }),
            ctx.json(projects.slice(page * pageSize - 1, page * pageSize + pageSize))
        );
    })
];

export default handlers;