/*!
 * Copyright (c) 2021, 2022, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Zhou Fang <zhou.fang@eclipse-foundation.org>
 *   Eric Poirier <eric.poirier@eclipse-foundation.org>
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 * 
 * SPDX-License-Identifier: EPL-2.0
 */

// UI utilities
export const displayErrMsg = (element, err = '', errText = 'Sorry, something went wrong, please try again later.') =>
  (element.innerHTML = `<div class="alert alert-danger" role="alert"><p><strong>Error ${err}</strong></p> <p>${errText}</p></div>`);

export const scrollToAnchor = () => {
  const elementId = location.hash.replace('#', '');
  const element = document.getElementById(elementId);
  element.scrollIntoView();
}

// API utilities
export const getNextPage = (linkHeader) => {
  if (!linkHeader) return;

  const links = linkHeader.split(', ');
  const nextLink = links.find(link => link.includes('rel="next"'));
  if (!nextLink) return;

  const nextUrl = nextLink.match(/<(.+)>/)[1];

  return nextUrl;
}

const absUrlPattern = /^[a-zA-Z]+:\/\//;
export const validateURL = (url) => {
  if (!url) return false;
  
  const isAbsolute = url.match(absUrlPattern);
  const base = isAbsolute ? undefined : window.location.href;
  
  let isValidate;
  try {
    // This will fail if the url is not valid
    new URL(url, base);
    isValidate = true;
  } catch (error) {
    isValidate = false;
  }
  return isValidate;
};

import querystring from 'querystring';

export const convertToQueryString = params => {
  // Filters out undefined params
  const filteredParams = Object.fromEntries(
    Object
      .entries(params)
      .filter(([_, v]) => v !== undefined)
  );

  return querystring.stringify(filteredParams);
}
